/**
 * A collection of tokens and constants used in `index.ts`.
 *
 * `import`ing this file should have basically no side-effects.
 */
/**
 * The canonical name of the extension, also used in CLI commands such as
 * `jupyter labextension disable`.
 */
export const NAME = "@jupyterhub/jupyter-server-proxy";
/**
 * The short namespace for commands, etc.
 */
export const NS = "server-proxy";
/**
 * The values for the `iframe` `sandbox` attribute.
 *
 * These are generally required for most non-trivial client applications, but
 * do not affect full browser tabs.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy/sandbox
 */
export const sandbox = Object.freeze([
    "allow-same-origin",
    "allow-scripts",
    "allow-popups",
    "allow-forms",
    "allow-downloads",
    "allow-modals",
]);
/**
 * The JSON schema for the open command arguments.
 *
 * @see https://lumino.readthedocs.io/en/latest/api/interfaces/commands.CommandRegistry.ICommandOptions.html
 */
export const argSchema = Object.freeze({
    type: "object",
    properties: {
        id: { type: "string" },
        title: { type: "string" },
        url: { type: "string", format: "uri" },
        newBrowserTab: { type: "boolean" },
    },
});
/**
 * The identifying string names for server proxy commands.
 *
 * Namespaces are real objects that exist at runtime in the browser
 *
 * @see https://www.typescriptlang.org/docs/handbook/namespaces.html
 */
export var CommandIDs;
(function (CommandIDs) {
    /* Opens a new server proxy tab */
    CommandIDs.open = `${NS}:open`;
})(CommandIDs || (CommandIDs = {}));
